@@ -9,7 +9,6 @@ use base qw/Data::ICal::Entry/;
 
 Data::ICal::Entry::Alarm::Audio - Represents an audio alarm in an iCalendar file
 
-
 =head1 SYNOPSIS
 
     my $valarm = Data::ICal::Entry::Alarm::Audio->new();
@@ -20,13 +19,13 @@ Data::ICal::Entry::Alarm::Audio - Represents an audio alarm in an iCalendar file
     );
 
     $vevent->add_entry($valarm);
-  
+
 =head1 DESCRIPTION
 
-A L<Data::ICal::Entry::Alarm::Audio> object represents an audio alarm attached
-to a todo item or event in an iCalendar file.  (Note that the iCalendar RFC
-refers to entries as "components".)  It is a subclass of L<Data::ICal::Entry>
-and accepts all of its methods.
+A L<Data::ICal::Entry::Alarm::Audio> object represents an audio alarm
+attached to a todo item or event in an iCalendar file.  (Note that the
+iCalendar RFC refers to entries as "components".)  It is a subclass of
+L<Data::ICal::Entry> and accepts all of its methods.
 
 =head1 METHODS
 
@@ -34,8 +33,8 @@ and accepts all of its methods.
 
 =head2 new
 
-Creates a new L<Data::ICal::Entry::Alarm::Audio> object; sets its C<ACTION> property
-to C<AUDIO>.
+Creates a new L<Data::ICal::Entry::Alarm::Audio> object; sets its
+C<ACTION> property to C<AUDIO>.
 
 =cut
 
@@ -56,13 +55,14 @@ sub ical_entry_type {'VALARM'}
 
 =head2 optional_unique_properties
 
-According to the iCalendar standard, the following properties may be specified
-at most one time for an audio alarm:
+According to the iCalendar standard, the following properties may be
+specified at most one time for an audio alarm:
 
 	duration repeat attach
 
-Note that if one of C<duration> or C<repeat> is specified, the other one must be also,
-though this module does not enforce that restriction.
+Note that if one of C<duration> or C<repeat> is specified, the other
+one must be also, though this module does not enforce that
+restriction.
 
 =cut
 
@@ -74,9 +74,10 @@ sub optional_unique_properties {
 
 =head2 mandatory_unique_properties
 
-According to the iCalendar standard, the C<trigger> property must be specified
-exactly once for an audio alarm.  (In addition, the C<action> property must be
-specified exactly once, but the module automatically sets it for you.)
+According to the iCalendar standard, the C<trigger> property must be
+specified exactly once for an audio alarm.  (In addition, the
+C<action> property must be specified exactly once, but the module
+automatically sets it for you.)
 
 =cut
 
@@ -88,12 +89,12 @@ sub mandatory_unique_properties {
 
 =head1 AUTHOR
 
-Jesse Vincent  C<< <jesse@bestpractical.com> >>
-
+Jesse Vincent C<< <jesse@bestpractical.com> >> with David Glasser,
+Simon Wistow, and Alex Vandiver
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2005, Best Practical Solutions, LLC.  All rights reserved.
+Copyright (c) 2005 - 2009, Best Practical Solutions, LLC.  All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
