@@ -9,7 +9,6 @@ use base qw/Data::ICal::Entry/;
 
 Data::ICal::Entry::Journal - Represents a journal entry in an iCalendar file
 
-
 =head1 SYNOPSIS
 
     my $vjournal = Data::ICal::Entry::Journal->new();
@@ -21,12 +20,13 @@ Data::ICal::Entry::Journal - Represents a journal entry in an iCalendar file
     );
 
     $calendar->add_entry($vjournal);
-  
+
 =head1 DESCRIPTION
 
-A L<Data::ICal::Entry::Journal> object represents a single journal entry in an iCalendar file.
-(Note that the iCalendar RFC refers to entries as "components".)  It is a subclass
-of L<Data::ICal::Entry> and accepts all of its methods.
+A L<Data::ICal::Entry::Journal> object represents a single journal
+entry in an iCalendar file.  (Note that the iCalendar RFC refers to
+entries as "components".)  It is a subclass of L<Data::ICal::Entry>
+and accepts all of its methods.
 
 =head1 METHODS
 
@@ -42,8 +42,8 @@ sub ical_entry_type {'VJOURNAL'}
 
 =head2 optional_unique_properties
 
-According to the iCalendar standard, the following properties may be specified
-at most one time for a journal entry:
+According to the iCalendar standard, the following properties may be
+specified at most one time for a journal entry:
 
     class  created  description  dtstart  dtstamp 
     last-modified  organizer  recurrence-id  sequence  status 
@@ -61,8 +61,8 @@ sub optional_unique_properties {
 
 =head2 optional_repeatable_properties
 
-According to the iCalendar standard, the following properties may be specified
-any number of times for a journal entry:
+According to the iCalendar standard, the following properties may be
+specified any number of times for a journal entry:
 
 	attach  attendee  categories  comment 
 	contact  exdate  exrule  related-to  rdate 
@@ -80,12 +80,12 @@ sub optional_repeatable_properties {
 
 =head1 AUTHOR
 
-Jesse Vincent  C<< <jesse@bestpractical.com> >> with David Glasser and Simon Wistow
-
+Jesse Vincent C<< <jesse@bestpractical.com> >> with David Glasser,
+Simon Wistow, and Alex Vandiver
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2005, Best Practical Solutions, LLC.  All rights reserved.
+Copyright (c) 2005 - 2009, Best Practical Solutions, LLC.  All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
